@@ -18,19 +18,14 @@ package machine
 
 import (
 	"bytes"
-	"errors"
 	"text/template"
 
-	"fmt"
-
-	clusterv1 "github.com/openshift/cluster-api/pkg/apis/cluster/v1alpha1"
-	machinev1 "github.com/openshift/cluster-api/pkg/apis/machine/v1beta1"
+	machinev1 "github.com/openshift/machine-api-operator/pkg/apis/machine/v1beta1"
 	openstackconfigv1 "sigs.k8s.io/cluster-api-provider-openstack/pkg/apis/openstackproviderconfig/v1alpha1"
 )
 
 type setupParams struct {
 	Token       string
-	Cluster     *clusterv1.Cluster
 	Machine     *machinev1.Machine
 	MachineSpec *openstackconfigv1.OpenstackProviderSpec
 
@@ -42,23 +37,17 @@ type setupParams struct {
 func init() {
 }
 
-func masterStartupScript(cluster *clusterv1.Cluster, machine *machinev1.Machine, script string) (string, error) {
+func masterStartupScript(machine *machinev1.Machine, script string) (string, error) {
 	machineSpec, err := openstackconfigv1.MachineSpecFromProviderSpec(machine.Spec.ProviderSpec)
 	if err != nil {
 		return "", err
 	}
 
 	params := setupParams{
-		Cluster:     cluster,
 		Machine:     machine,
 		MachineSpec: machineSpec,
 	}
 
-	if cluster != nil {
-		params.PodCIDR = getSubnet(cluster.Spec.ClusterNetwork.Pods)
-		params.ServiceCIDR = getSubnet(cluster.Spec.ClusterNetwork.Services)
-	}
-
 	masterStartUpScript := template.Must(template.New("masterStartUp").Parse(script))
 
 	var buf bytes.Buffer
@@ -68,32 +57,16 @@ func masterStartupScript(cluster *clusterv1.Cluster, machine *machinev1.Machine,
 	return buf.String(), nil
 }
 
-func nodeStartupScript(cluster *clusterv1.Cluster, machine *machinev1.Machine, token, script string) (string, error) {
+func nodeStartupScript(machine *machinev1.Machine, token, script string) (string, error) {
 	machineSpec, err := openstackconfigv1.MachineSpecFromProviderSpec(machine.Spec.ProviderSpec)
 	if err != nil {
 		return "", err
 	}
 
-	GetMasterEndpoint := func() (string, error) {
-		if cluster == nil {
-			return "", nil
-		} else if len(cluster.Status.APIEndpoints) == 0 {
-			return "", errors.New("no cluster status found")
-		}
-		return getEndpoint(cluster.Status.APIEndpoints[0]), nil
-	}
-
 	params := setupParams{
-		Token:             token,
-		Cluster:           cluster,
-		Machine:           machine,
-		MachineSpec:       machineSpec,
-		GetMasterEndpoint: GetMasterEndpoint,
-	}
-
-	if cluster != nil {
-		params.PodCIDR = getSubnet(cluster.Spec.ClusterNetwork.Pods)
-		params.ServiceCIDR = getSubnet(cluster.Spec.ClusterNetwork.Services)
+		Token:       token,
+		Machine:     machine,
+		MachineSpec: machineSpec,
 	}
 
 	nodeStartUpScript := template.Must(template.New("nodeStartUp").Parse(script))
@@ -104,15 +77,3 @@ func nodeStartupScript(cluster *clusterv1.Cluster, machine *machinev1.Machine, t
 	}
 	return buf.String(), nil
 }
-
-func getEndpoint(apiEndpoint clusterv1.APIEndpoint) string {
-	return fmt.Sprintf("%s:%d", apiEndpoint.Host, apiEndpoint.Port)
-}
-
-// Just a temporary hack to grab a single range from the config.
-func getSubnet(netRange clusterv1.NetworkRanges) string {
-	if len(netRange.CIDRBlocks) == 0 {
-		return ""
-	}
-	return netRange.CIDRBlocks[0]
-}
